# GeoLite

GeoLite: Simplifying Spatial - Your lightweight companion when working with geospatial data in Python.

| :exclamation:  Is in active development  :exclamation:   |
|----------------------------------------------------------|

## Installation

```bash
pip install geolite
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

